@@ -65,24 +65,6 @@ sub ACTION_code {
     # mark sucessfully finished build
     $self->touch_build_done_marker;
   }
-  
-  #### as we are building just a static library the following is not (perhaps) necessary
-  #if($^O eq 'darwin') {
-  #  my $sharedir     = eval {File::ShareDir::dist_dir('Alien-Box2D')} || '';
-  #  my $dlext        = 'so|dylib|bundle';
-  #  my ($libname)    = $self->find_file("$build_out/lib", qr/\.$dlext[\d\.]+$/);
-  #  if($self->invoked_action() eq 'test') {
-  #    my $cmd = "install_name_tool -id $libname $libname";
-  #    print "Changing lib id ...\n(cmd: $cmd)\n";
-  #    $self->do_system($cmd);
-  #  }
-  #  elsif($self->invoked_action() eq 'install') {
-  #    $libname         = $1 if $libname =~ /([^\\\/]+)$/;
-  #    my $cmd = "install_name_tool -id $sharedir/$share_subdir/lib/$libname sharedir/$share_subdir/lib/$libname";
-  #    print "Changing lib id ...\n(cmd: $cmd)\n";
-  #    $self->do_system($cmd);
-  #  }
-  #}
 
   $self->SUPER::ACTION_code;
 }
@@ -172,9 +154,14 @@ sub build_binaries {
   my $cxxflags = '-O3';
   $cxxflags .= ' -fPIC' if $Config{cccdlflags} =~ /-fPIC/;
   # MacOSX related flags
-  $cxxflags .= ' -arch x86_64' if $Config{ccflags} =~ /-arch x86_64/;
-  $cxxflags .= ' -arch i386' if $Config{ccflags} =~ /-arch i386/;
-  $cxxflags .= ' -arch ppc' if $Config{ccflags} =~ /-arch ppc/;
+  # 'as' for 'arch' can be in /usr/libexec/gcc/darwin/<arch_type>/as or in /usr/local/libexec/gcc/darwin/<arch_type>/as
+  foreach my $arch (qw(x86_64 i386 ppc)) {
+    if($Config{ccflags} =~ /-arch \Q$arch\E/
+    && (-e "/usr/libexec/gcc/darwin/$arch/as"
+     || -e "/usr/local/libexec/gcc/darwin/$arch/as")) {
+      $cxxflags .= " -arch $arch";
+    }
+  }
 
   ### workaround for http://www.cpantesters.org/cpan/report/16e1fb62-8bc3-11e0-a7f7-6524785ebe45
   #On solaris, some tools like 'ar' are not in the default PATH, but in /usr/???/bin
@@ -182,7 +169,7 @@ sub build_binaries {
   if ($^O eq 'solaris' && system('ar -V') < 0) {    
     for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
       if (-x "$_/ar") {
-        $ar = "AR=$_/ar";
+        $ar = "$_/ar";
         last;
       }
     }
